close all
N=80;
[bvp,info]=fc_vfemp1.samples.setBVPElectrostatic2D01(N,'verbose',2);

fprintf('3. Solving 2D Electrostatic BVP\n')
phi=bvp.solve();

fprintf('4. Graphic representations\n');
options=fc_tools.graphics.DisplayFigures('nfig',7);
interpreter=@(x) fc_tools.graphics.interpreter(x);

Th=bvp.Th;

figure(1)
Th.plotmesh('legend',true)
set(legend(),options.legend{:})
axis image
set(gca,options.axes{:})

figure(2)
Th.plotmesh('color',[0.8,0.8,0.8])
Th.plotmesh('d',1,'LineWidth',1.5,'legend',true)
set(legend(),options.legend{:})
axis image
set(gca,options.axes{:})

figure(3)
Th.plotmesh('d',1,'color',[0,0,0])
hold on
Th.plot(phi,'EdgeColor','None')
axis image;axis off;
set(colorbar(),options.colorbar{:})
Th.plotiso(phi,'niso',20,'color','w','LineWidth',1) 
Th.plotmesh('d',1,'color','w','LineWidth',1.5)
shading interp
title(interpreter('potentiel $\varphi$'),options.interpreter{:},options.title{:})

figure(4)
Th.plotmesh('color',[0.85,0.85,0.85])
hold on
Th.plotmesh('d',1,'color',[0,0,0])
[~,~,cax]=Th.plotiso(phi,'niso',25,'isocolorbar',true,'format','%.3f');
set(cax,options.colorbar{:})
axis image;axis off;
title(interpreter('potentiel $\varphi$'),options.interpreter{:},options.title{:})

% Computation of the electric field E
Lop=Loperator(2,2,[],[],{-1,0},[]);
Ex=Lop.apply(Th,phi); 
Lop=Loperator(2,2,[],[],{0,-1},[]);
Ey=Lop.apply(Th,phi); 
E=[Ex,Ey]';

idxlab=Th.find(2,10);
figure(5)
Th.plotmesh('d',1,'color','k')
hold on
[~,~,cax]=Th.plotiso(phi,'niso',25,'isocolorbar',true,'format','%.3f');
set(cax,options.colorbar{:})
Th.sTh{idxlab}.plotVectorField(E)
axis image;axis off;
title(interpreter('potentiel $\varphi$ and electric field $E$'),options.interpreter{:},options.title{:})

figure(6)
ENorm=sqrt(Ex.^2+Ey.^2);
Th.plot(ENorm,'EdgeColor','None')
hold on
axis image;axis off;
set(colorbar(),options.colorbar{:})
Th.plotiso(ENorm,'niso',20,'color','w','LineWidth',1) 
Th.plotmesh('d',1,'color','k','LineWidth',1.5)
shading interp
title(interpreter('Norm of the electric field $E$'),options.interpreter{:},options.title{:})

figure(7)
Th.plotmesh('d',1,'color',[0,0,0])
hold on
[~,~,cax]=Th.plotiso(ENorm,'niso',25,'isocolorbar',true,'format','%.3f');
set(cax,options.colorbar{:})
axis image;axis off;
title(interpreter('Norm of the electric field $E$'),options.interpreter{:},options.title{:})

